@@ -270,7 +270,7 @@ class LocalRun(RunBase):
                               doUserInputFiles=True,
                               doSimToolInputFile=False)
 
-         prerunFiles = os.listdir(os.getcwd())
+         prerunFiles = os.listdir(self.outdir)
          prerunFiles.append(self.nbName)
 
          # FIXME: run in background. wait or check status.
@@ -458,17 +458,28 @@ class Run:
        If the tool is not published, and cache is True, a local user cache will be used.
 
        Args:
-           simtoolName: The name of a published SimTool or the path to a notebook
-               containing a SimTool.
-           simtoolRevision: The revision of a published SimTool
-           inputs: A SimTools Params object or a dictionary of key-value pairs.
-           runName: An optional name for the run.  A unique name will be generated
-               if none was supplied.
+           simToolLocation:  A list containing information on SimTool notebook
+               location and status.
+           inputs:  A SimTools Params object or a dictionary of key-value pairs.
+           runName:  An optional name for the run.  A unique name will be generated
+               if no name is supplied.
+           remoteAttributes:  A list of parameters used for submission to offsite
+               resource.  In the absense of remoteAttributes the notebook execution
+               will occur locally.
            cache:  If the SimTool was run with the same inputs previously, return
                the results from the cache.  Otherwise cache the results.  If this
-               parameter is False, do neither of these.
-           venue:  'submit' to use submit.  'local' to use 'submit --local'.  Default
-               is None, which runs locally without submit.
+               parameter is False, do neither of these.  The SimTool must be published
+               to access the global cache, otherwise each user has a local cache
+               that can be accesed.
+           venue:  'noSubmit' to ignore presense of submit.
+                   'local' to use 'submit --local'.
+                   'trustedLocal' to use 'submit --local' as the trusted user for 
+                       global cache interaction.
+                   'remote' to use 'submit' to execute job on remote resource.
+                   'trustedRemote' to use 'submit' to execute job on remote resource
+                       as the trusted user for global cache interaction.
+                   Default is None, in which case venue is determined based on the
+                   availability of submit and the other arguments.
        Returns:
            A Run object.
        """
@@ -506,6 +517,8 @@ class Run:
          newclass = TrustedUserLocalRun(simToolLocation,inputs,runName,cache)
       elif venue == 'trustedRemote': 
          newclass = TrustedUserRemoteRun(simToolLocation,inputs,runName,remoteRunAttributes,cache)
+      elif venue == 'noSubmit':
+         newclass = LocalRun(simToolLocation,inputs,runName,cache)
       elif venue is None:
          newclass = LocalRun(simToolLocation,inputs,runName,cache)
       else:
